@@ -147,18 +147,23 @@ def select_xlsx(to_disable):
     final_label = tk.Label(root)
     final_label.place(x=150,y=155)
     
-    if 'shifts' not in pd.ExcelFile(root.xlsx).sheet_names: 
+    if root.xlsx == '':
+        xlsx_label.config( text='<- Select exp. data file                                     ')
+        return
+    
+    elif 'shifts' not in pd.ExcelFile(root.xlsx).sheet_names: 
         xlsx_label.config(text='"shifts" sheet wasn not found. Try again')
         root.xlsx = ''
         return
     
-    final_label.config(text=f'Processing ...                      ')
-    xlsx_label.config(text=root.xlsx)
-    for button in to_disable:
-        button['state']='disabled'
+    else: 
+        root.after(2000, root.quit)
+        
+        final_label.config(text=f'Processing ...                      ')
+        xlsx_label.config(text=root.xlsx)
+        for button in to_disable:
+            button['state']='disabled'
     
-    
-    root.quit()
     return
 
 def isomer_count():
